@@ -1,4 +1,3 @@
-from typing import Union
 try:
     import simdjson as _json
 except ImportError:
@@ -12,7 +11,7 @@ def simdjson_dumps(
     default=None,
     sort_keys=False,
     rtype='bytes',
-) -> Union[bytes, str]:
+) -> bytes | str:
     """
     Wrapper function for dumping python values to JSON,
     to make it easy to swap out JSON library project-wide.
@@ -24,7 +23,7 @@ def simdjson_dumps(
     return value
 
 
-def simdjson_loads(value: Union[bytes, str]):
+def simdjson_loads(value: bytes | str):
     """
     Wrapper function for loading string to python values,
     for consistent value parsing and to make it easy to
@@ -33,7 +32,6 @@ def simdjson_loads(value: Union[bytes, str]):
     try:
         return _json.loads(value)
     except Exception as e:
-
         try:
             return _json.loads(clean_byte_string(value))
         except Exception:
