@@ -35,7 +35,7 @@ except ImportError:
     _cy_parse_query_string = None
 
 # NOTE(kgriffs): See also RFC 3986
-_UNRESERVED = ('ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' '0123456789' '-._~')
+_UNRESERVED = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~'
 
 # NOTE(kgriffs): See also RFC 3986
 _DELIMITERS = ":/?#[]@!$&'()*+,;="
@@ -50,7 +50,6 @@ _PYPY = platform.python_implementation() == 'PyPy'
 
 
 def _create_char_encoder(allowed_chars):
-
     lookup = {}
 
     for code_point in range(256):
@@ -65,7 +64,6 @@ def _create_char_encoder(allowed_chars):
 
 
 def _create_str_encoder(is_value):
-
     allowed_chars = _UNRESERVED if is_value else _ALL_ALLOWED
     allowed_chars_plus_percent = allowed_chars + '%'
     encode_char = _create_char_encoder(allowed_chars)
@@ -427,20 +425,20 @@ def parse_host(host, default_port=None):
         # IPv6 address with a port
         pos = host.rfind(']:')
         if pos != -1:
-            return (host[1:pos], int(host[pos + 2:]))
+            return host[1:pos], int(host[pos + 2 :])
         else:
-            return (host[1:-1], default_port)
+            return host[1:-1], default_port
 
     pos = host.rfind(':')
     if (pos == -1) or (pos != host.find(':')):
         # Bare domain name or IP address
-        return (host, default_port)
+        return host, default_port
 
     # NOTE(kgriffs): At this point we know that there was
     # only a single colon, so we should have an IPv4 address
     # or a domain name plus a port
     name, _, port = host.partition(':')
-    return (name, int(port))
+    return name, int(port)
 
 
 def unquote_string(quoted):
