@@ -1,4 +1,5 @@
 import yaml
+
 try:
     from yaml.cyaml import (
         CDumper as Dumper,
@@ -7,7 +8,7 @@ try:
         CSafeLoader as SafeLoader,
     )
 except ImportError:
-    from yaml import Dumper, Loader, SafeDumper, SafeLoader
+    from yaml import Dumper, Loader, SafeDumper, SafeLoader  # type: ignore[assignment]
 
 
 def yaml_dump(data, stream=None, **kwargs):
